' Loop Recorder Pro Archive Cleanup 1.1
' Deletes old files from the sound archive.
'
' for
'
' Loop Recorder Pro
' http://www.looprecorder.de
'
' This program is freeware for users of Loop Recorder Pro
'
' This script is for advanced users only and is not supported.
' It requires the Windows Scripting Host
' http://msdn.microsoft.com/library/default.asp?url=/downloads/list/webdev.asp
'
' NO WARRANTY
'
' BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO
' WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY
' APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE
' COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM
' "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR
' IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
' WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
' PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF
' THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE,
' YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR
' CORRECTION.
'
' IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN
' WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY
' MODIFY THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR
' DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR
' CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
' THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA
' BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD
' PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER
' PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF
' THE POSSIBILITY OF SUCH DAMAGES.
'
'  2003 Thomas Riechmann, Gerald Riechmann
' http://www.looprecorder.de
' info@looprecorder.de
'
' ============================================================================
' CONFIGURATION

' Unit: Seconds: "s" Hours: "h" Days: "d" Months: "m"
' 42 days (6 weeks):
Const deleteAfter = 42, timeUnit = "d"

' 3 months:
' Const deleteAfter = 3, timeUnit = "m"

' 300 seconds (5 minutes, for testing):
' Const deleteAfter = 300, timeUnit = "s"

' Ask before deleting? yes = False, no = True (True will DELETE WITHOUT A WARNING!!!)
Const quietMode = False

' Give the user the specified number of seconds to cancel the deletion. (Only for quietMode = False)
Const popupSeconds = 20

' Simulate it only? True = yes, False = No
Const simulationMode = True ' True|False

' ============================================================================

Const scriptTitle = "Loop Recorder Pro - Archive Cleanup"
Const LRPRegistry = "HKEY_CURRENT_USER\Software\LoopRec-Application\LOOPRECP\Default Settings\"

Dim loopRecFile, loopRecFolder, loopRecFolderObj, thisFile, thisFileObj
Dim popupStatus, deleteSize, settingLoopMode
Dim fso, WSHShell
Dim deleteFiles()
Dim removeTrashStatus, trashFilesStatus
Dim driveName, driveObj
Dim logFile

Set fso = CreateObject("Scripting.FileSystemObject")
Set WSHShell = CreateObject("WScript.Shell")
Const ForAppending = 8

loopRecFile = WSHShell.RegRead(LRPRegistry & "Target File")
loopRecFolder = fso.GetParentFolderName(loopRecFile)

driveName = fso.GetDriveName(loopRecFolder)
Set driveObj = fso.GetDrive(driveName)

logFile = fso.BuildPath(loopRecFolder, scriptTitle & ".log")

' MsgBox spaceOnDrive(driveObj)

settingLoopMode = WSHShell.RegRead(LRPRegistry & "Loop Mode")

If simulationMode Then
	MsgBox "Simulation Mode, no files are going to be deleted."
End If

If (settingLoopMode <> 1) and (settingLoopMode <> 2) Then
	MsgBox "Loop Recorder Pro is not set to archive or vox mode! Read the help (Overview/Recording Modes/Archive Mode)"
	WScript.Quit
End If


If not fso.FolderExists(loopRecFolder) Then
	MsgBox "Folder does not exist: " & loopRecFolder
	WScript.Quit
End If

Dim filesPattern, testFile, matchFilesPattern, replaceRegExp, replaceMacros
Set replaceRegExp = New RegExp
replaceRegExp.Pattern = "([\[\]\{\}\(\)+.])"
replaceRegExp.Global = True

Set replaceMacros = New RegExp
replaceMacros.Pattern = "\%\w"
replaceMacros.Global = True

filesPattern = fso.GetFileName(loopRecFile)
filesPattern = replaceRegExp.replace(filesPattern, "\$1")
filesPattern = replaceMacros.replace(filesPattern, "\d*")
filesPattern = "^" & filesPattern & "$"

If not replaceMacros.Test(loopRecFile) Then
	MsgBox "The default file name for Loop Recorder Pro files (" & loopRecFile & ") does not contain any %X values, please read the help how to set up the archive mode!"
	WScript.Quit
End If

Set matchFilesPattern = New RegExp
matchFilesPattern.Pattern = filesPattern

Dim allFilesSize, allFilesCount, delFilesSize, delFilesCount, delFilesList
allFilesSize = 0
allFilesCount = 0
delFilesSize = 0
delFilesCount = 0
delFilesList = ""

Set loopRecFolderObj = fso.GetFolder(loopRecFolder)
For Each thisFile in loopRecFolderObj.Files
	If matchFilesPattern.Test(thisFile.name) Then
		allFilesSize = allFilesSize + thisFile.Size
		allFilesCount = allFilesCount + 1
		If DateDiff(timeUnit, thisFile.DateLastModified, Now) > deleteAfter Then
			ReDim Preserve deleteFiles(delFilesCount)
			deleteFiles(delFilesCount) = thisFile.Path
			delFilesCount = delFilesCount + 1
			delFilesSize = delFilesSize + thisFile.Size
			delFilesList = delFilesList & vbCrLf & thisFile.Name
		End If
		' MsgBox thisFile
	End If
Next

logLine "Starting cleanup. Found " & delFilesCount & " of " & allFilesCount & " File(s) to delete."

If delFilesCount < 1 Then
	' logLine "Nothing to do, bye."
	If not quietMode Then
		popupStatus = WSHShell.Popup("Nothing to delete!" & vbCrLf & _
		"Found " & allFilesCount & " matching File(s) in " & loopRecFolder & _
		" (" & fn(allFilesSize) & ")" & vbCrLf & _
		"None was older than " & deleteAfter & timeUnit  & "." & vbCrLf & _
		vbCrLf & spaceOnDrive(driveObj) & vbCrLf & _
		vbCrLf & "(This message box closes automatically.)", popupSeconds, scriptTitle, vbOkOnly + vbInformation)

	End If
	WScript.Quit
End If

If not quietMode Then
	popupStatus = WSHShell.Popup("Deleting " & delFilesCount & " of " & allFilesCount & " File(s) in " & loopRecFolder & " (" & fn(delFilesSize) & " of " & fn(allFilesSize) & ") in " & popupSeconds & " seconds!" & vbCrLf & vbCrLf & "Click CANCEL to keep the files!", popupSeconds, scriptTitle, vbExclamation + vbOkCancel + vbDefaultButton2)
	If popupStatus = vbCancel Then
		logLine "User canceled cleanup, terminating."
		WScript.Quit
	End If
End If

For Each thisFile in deleteFiles
	Set thisFileObj = fso.getFile(thisFile)
	logLine "Deleting: " & thisFile & " (age: " & DateDiff(timeUnit, thisFileObj.DateLastModified, Now) & timeUnit & ")"
	' MsgBox thisFile
	If not simulationMode Then
		fso.DeleteFile thisFile
	End If
Next

logLine "Cleanup done. " & spaceOnDrive(driveObj)

If not quietMode Then
	popupStatus = WSHShell.Popup("Deleted " & delFilesCount & " of " & allFilesCount & " File(s) in " & loopRecFolder & " (" & fn(delFilesSize) & " of " & fn(allFilesSize) & ")." & vbCrLf & spaceOnDrive(driveObj) & vbCrLf & _
		vbCrLf & "(This message box closes automatically.)", popupSeconds, scriptTitle, vbOkOnly + vbInformation)
End If

If simulationMode Then
	WSHShell.Run "notepad.exe """ & logFile & """", , vbFalse
	MsgBox "Simulation Mode: opening the log file..."
End If


Function fn(bytes)
	fn = FormatNumber(bytes/1024/1024, 0) & " MB"
End Function

Function spaceOnDrive(driveObj)
	spaceOnDrive = "Space on [" & driveObj.path & "]: " & fn(driveObj.FreeSpace)
End Function

Sub logLine(text)
	Dim logFileObj
	Set logFileObj = fso.OpenTextFile(logFile, ForAppending, True)

	If simulationMode Then
		text = text & " (Simulation)"
	End If

	logFileObj.WriteLine Now & " " & text
	logFileObj.Close
End Sub
